﻿// -*- C++ -*-
/*!
 * @file  ConvertVel.cpp
 * @brief Convert from TimedFloat to TimedVelocity
 * @date $Date$
 *
 * $Id$
 */

#include "ConvertVel.h"

// Module specification
// <rtc-template block="module_spec">
static const char* convertvel_spec[] =
  {
    "implementation_id", "ConvertVel",
    "type_name",         "ConvertVel",
    "description",       "Convert from TimedFloat to TimedVelocity",
    "version",           "1.0.0",
    "vendor",            "FSK",
    "category",          "Converter",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
ConvertVel::ConvertVel(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_infloatIn("InFloat", m_infloat),
    m_outVelocityOut("OutVelocity", m_outVelocity)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
ConvertVel::~ConvertVel()
{
}



RTC::ReturnCode_t ConvertVel::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("InFloat", m_infloatIn);

  // Set OutPort buffer
  addOutPort("OutVelocity", m_outVelocityOut);

  // Set service provider to Ports

  // Set service consumers to Ports

  // Set CORBA Service Ports

  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t ConvertVel::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ConvertVel::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ConvertVel::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t ConvertVel::onActivated(RTC::UniqueId ec_id)
{
    m_outVelocity.data.va = 0;
    m_outVelocity.data.vx = 0;
    m_outVelocity.data.vy = 0;

    m_outVelocityOut.write();
  return RTC::RTC_OK;
}


RTC::ReturnCode_t ConvertVel::onDeactivated(RTC::UniqueId ec_id)
{
    m_outVelocity.data.va = 0;
    m_outVelocity.data.vx = 0;
    m_outVelocity.data.vy = 0;

    m_outVelocityOut.write();
  return RTC::RTC_OK;
}


RTC::ReturnCode_t ConvertVel::onExecute(RTC::UniqueId ec_id)
{
    float vx = 0;
    float vy = 0;
    float omega = 0;
    float Vx = 0;
    float thread = 0.05925;//EV3横幅

    if (m_infloatIn.isNew())
    {
        m_infloatIn.read();

        vx = m_infloat.data[0];
        vy = m_infloat.data[1];
        Vx = (vx + vy) / 2;
        omega = (vy - vx) / (2 *thread);
        if (Vx < 0)omega = -1 * omega;

        m_outVelocity.data.vx = Vx/1000;
        m_outVelocity.data.vy = 0;
        m_outVelocity.data.va = omega/1000;
        std::cout << "Vx:" << Vx << " Va:" << omega << std::endl;
        m_outVelocityOut.write();

    }


  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t ConvertVel::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ConvertVel::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ConvertVel::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ConvertVel::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t ConvertVel::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{

  void ConvertVelInit(RTC::Manager* manager)
  {
    coil::Properties profile(convertvel_spec);
    manager->registerFactory(profile,
                             RTC::Create<ConvertVel>,
                             RTC::Delete<ConvertVel>);
  }

};


